==============
 temperatures
==============

``temperatures`` is a Python program that gathers temperatures from hard
disks, CPU and GPU and presents them in a concise string suitable to be
fed to XFCE's Generic Monitor panel plugin or similar.

https://github.com/luismsgomes/temperatures

Copyright (c) 2020 Luís Gomes <luismsgomes@gmail.com>

Usage
-----

This program takes no input and no options.

It is assumed that `hddtempd` daemon is running and listening on port 7634.
